#
# spec file for package python-nilearn
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
# SciPy 1.6.0 dropped support for Python 3.6
%define         skip_python36 1
Name:           python-nilearn
Version:        0.7.1
Release:        bp155.2.9
Summary:        Statistical learning tool for neuroimaging
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/nilearn/nilearn
Source:         https://github.com/nilearn/nilearn/archive/%{version}.tar.gz#/nilearn-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-joblib >= 0.12
Requires:       python-matplotlib >= 2.0
Requires:       python-nibabel >= 2.0.2
Requires:       python-numpy >= 1.11
Requires:       python-requests
Requires:       python-scikit-learn >= 0.19
Requires:       python-scipy >= 0.19
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module joblib >= 0.12}
BuildRequires:  %{python_module matplotlib >= 2.0}
BuildRequires:  %{python_module nibabel >= 2.0.2}
BuildRequires:  %{python_module numpy >= 1.11}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module scikit-learn >= 0.19}
BuildRequires:  %{python_module scipy >= 0.19}
# /SECTION
%python_subpackages

%description
Nilearn is a Python module for statistical learning on
NeuroImaging data.

%prep
%setup -q -n nilearn-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Test try to build the doc and run examples...
rm -rf doc/ examples/
# Disable tests that require a network connection
# Disable tests requiring to be executed without xdist (serialization issue): test_tikhonov_regularization_vs_graph_net or test_connectivity_measure_outputs or test_canica_square_img or test_with_globbing_patterns_with_single_subject or test_dict_learning
# https://github.com/nilearn/nilearn/issues/2608 - test_clean_confounds
# https://github.com/nilearn/nilearn/issues/2610 - test_reorder_img_mirror
%pytest -n auto -k 'not (test_fetch_ or test_get_batch or test_scroll_server_results or test_simple_download or test_fill_html_template or test_temp_file_removing or test_view_img_on_surf or test_view_surf or test_resample_img_segmentation_fault or test_tikhonov_regularization_vs_graph_net or test_connectivity_measure_outputs or test_canica_square_img or test_with_globbing_patterns_with_single_subject or test_dict_learning or test_clean_confounds or test_reorder_img_mirror)'

%files %{python_files}
%doc AUTHORS.rst README.rst
%license LICENSE
%{python_sitelib}/nilearn
%{python_sitelib}/nilearn-%{version}*-info

%changelog
* Fri Apr  9 2021 Markéta Machová <mmachova@suse.com>
- Update to 0.7.1
  * New atlas fetcher nilearn.datasets.fetch_atlas_difumo to download
    Dictionaries of Functional Modes, or “DiFuMo”, that can serve as
    atlases to extract functional signals with different dimensionalities.
  * nilearn.decoding.Decoder and nilearn.decoding.DecoderRegressor is now
    implemented with random predictions to estimate a chance level.
  * Some functions are now implemented with new display mode Mosaic. That
    implies plotting 3D maps in multiple columns and rows in a single axes.
- Drop nilearn-fix-aarch64.patch
* Fri Jan 29 2021 Ben Greiner <code@bnavigator.de>
- Skip python36 build because Tumbleweed updates to SciPy 1.6.0
  which dropped support for Python 3.6 (NEP 29)
* Fri Nov 20 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add runtime deps: python-requests
* Mon Nov 16 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 0.7.0
- Add patch to fix aarch64 test:
  * nilearn-fix-aarch64.patch
- Drop upstreamed patches:
  * fix-test_save_cmap.patch
  * update-numpy-warning.patch
- Disable 'test_clean_confounds' and 'test_reorder_img_mirror '
  until we have a fix. See:
    https://github.com/nilearn/nilearn/issues/2608
    https://github.com/nilearn/nilearn/issues/2610
* Wed Oct 14 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Backport patches to fix some tests:
  * update-numpy-warning.patch - https://github.com/nilearn/nilearn/pull/2530
  * fix-test_save_cmap.patch   - https://github.com/nilearn/nilearn/pull/2543
* Wed Apr 29 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use xdist to speedup the tests to take less than 30 mins
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to version 0.6.1
  + ENHANCEMENTS
  * html pages use the user-provided plot title, if any, as their title
  + Fixes
  * Fetchers for developmental_fmri and localizer datasets resolve URLs correctly.
* Mon Jan  6 2020 Todd R <toddrme2178@gmail.com>
- Update to version 0.6.0
  + HIGHLIGHTS
  * Python2 and 3.4 are no longer supported. We recommend upgrading to Python 3.6 minimum.
  * Support for Python3.5 wil be removed in the 0.7.x release.
    Users with a Python3.5 environment will be warned at their first Nilearn import.
  * joblib is now a dependency
  * Minimum supported versions of packages have been bumped up.
    > Matplotlib -- v2.0
    > Scikit-learn -- v0.19
    > Scipy -- v0.19
  + NEW
  * A new method for :class:`nilearn.input_data.NiftiMasker` instances
    for generating reports viewable in a web browser, Jupyter Notebook, or VSCode.
  * A new function :func:`nilearn.image.get_data` to replace the deprecated
    nibabel method `Nifti1Image.get_data`. Now use `nilearn.image.get_data(img)`
    rather than `img.get_data()`. This is because Nibabel is removing the
    `get_data` method. You may also consider using the Nibabel
    `Nifti1Image.get_fdata`, which returns the data cast to floating-point.
    See https://github.com/nipy/nibabel/wiki/BIAP8 .
    As a benefit, the `get_data` function works on niimg-like objects such as
    filenames (see http://nilearn.github.io/manipulating_images/input_output.html ).
  * Parcellation method ReNA: Fast agglomerative clustering based on recursive
    nearest neighbor grouping.
    Yields very fast & accurate models, without creation of giant
    clusters.
  * Plot connectome strength
    Use :func:`nilearn.plotting.plot_connectome_strength` to plot the strength of a
    connectome on a glass brain.  Strength is absolute sum of the edges at a node.
  * Optimization to image resampling
  * New brain development fMRI dataset fetcher
    :func:`nilearn.datasets.fetch_development_fmri` can be used to download
    movie-watching data in children and adults. A light-weight dataset
    implemented for teaching and usage in the examples. All the connectivity examples
    are changed from ADHD to brain development fmri dataset.
  + ENHANCEMENTS
  * :func:`nilearn.plotting.view_img_on_surf`, :func:`nilearn.plotting.view_surf`
    and :func:`nilearn.plotting.view_connectome` can display a title, and allow
    disabling the colorbar, and setting its height and the fontsize of its ticklabels.
  * Rework of the standardize-options of :func:`nilearn.signal.clean` and the various Maskers
    in `nilearn.input_data`. You can now set `standardize` to `zscore` or `psc`. `psc` stands
    for `Percent Signal Change`, which can be a meaningful metric for BOLD.
  * Class :class:`nilearn.input_data.NiftiLabelsMasker` now accepts an optional
    `strategy` parameter which allows it to change the function used to reduce
    values within each labelled ROI. Available functions include mean, median,
    minimum, maximum, standard_deviation and variance.
    This change is also introduced in :func:`nilearn.regions.img_to_signals_labels`.
  * :func:`nilearn.plotting.view_surf` now accepts surface data provided as a file
    path.
  + CHANGES
  * :func:`nilearn.plotting.plot_img` now has explicit keyword arguments `bg_img`,
    `vmin` and `vmax` to control the background image and the bounds of the
    colormap. These arguments were already accepted in `kwargs` but not documented
    before.
  + FIXES
  * :class:`nilearn.input_data.NiftiLabelsMasker` no longer truncates region means to their integral part
    when input images are of integer type.
  * The arg `version='det'` in :func:`nilearn.datasets.fetch_atlas_pauli_2017` now  works as expected.
  * `pip install nilearn` now installs the necessary dependencies.
  * Lots of other fixes in documentation and examples. More detailed change list follows:
- Drop python2 support
* Fri Jul 26 2019 Todd R <toddrme2178@gmail.com>
- Initial version
